Struct ck_doge_types::block::BlockHeader

source ·
pub struct BlockHeader {
    pub version: u32,
    pub prev_blockhash: BlockHash,
    pub merkle_root: TxMerkleNode,
    pub time: u32,
    pub bits: u32,
    pub nonce: u32,
}

Fields

version: u32

Block version, now repurposed for soft fork signalling.

prev_blockhash: BlockHash

Reference to the previous block in the chain.

merkle_root: TxMerkleNode

The root hash of the merkle tree of transactions in the block.

time: u32

The timestamp of the block, as claimed by the miner.

bits: u32

The target value below which the blockhash must lie.

nonce: u32

The nonce, selected to obtain a low enough blockhash.

Implementations

source

impl BlockHeader

source

pub const VERSION_AUXPOW: u32 = 256u32

source

pub const VERSION_CHAIN_START: u32 = 65_536u32

Bits above are reserved for the auxpow chain ID.

source

pub fn is_null(&self) -> bool

source

pub fn is_auxpow(&self) -> bool

source

pub fn chain_id(&self) -> u32

source

pub fn is_legacy(&self) -> bool

source

pub fn block_hash(&self) -> BlockHash