Struct ck_doge_types::block::BlockHeader
source · pub struct BlockHeader {
pub version: u32,
pub prev_blockhash: BlockHash,
pub merkle_root: TxMerkleNode,
pub time: u32,
pub bits: u32,
pub nonce: u32,
}Fields
version: u32Block version, now repurposed for soft fork signalling.
prev_blockhash: BlockHashReference to the previous block in the chain.
merkle_root: TxMerkleNodeThe root hash of the merkle tree of transactions in the block.
time: u32The timestamp of the block, as claimed by the miner.
bits: u32The target value below which the blockhash must lie.
nonce: u32The nonce, selected to obtain a low enough blockhash.
Implementations
sourceimpl BlockHeader
impl BlockHeader
pub const VERSION_AUXPOW: u32 = 256u32
sourcepub const VERSION_CHAIN_START: u32 = 65_536u32
pub const VERSION_CHAIN_START: u32 = 65_536u32
Bits above are reserved for the auxpow chain ID.
pub fn is_null(&self) -> bool
pub fn is_auxpow(&self) -> bool
pub fn chain_id(&self) -> u32
pub fn is_legacy(&self) -> bool
pub fn block_hash(&self) -> BlockHash